@@ -1,4 +1,3 @@
-import six
 import uuid
 import json
 import logging
@@ -11,7 +10,7 @@ from requests_toolbelt import MultipartEncoder
 
 from alephclient import settings
 from alephclient.errors import AlephException
-from alephclient.util import backoff
+from alephclient.util import backoff, prop_push
 
 log = logging.getLogger(__name__)
 MIME = 'application/octet-stream'
@@ -108,18 +107,18 @@ class AlephAPI(object):
             filters.append(('schemata', schemata))
         if schema is None and schemata is None:
             filters.append(('schemata', 'Thing'))
-        url = self._make_url("entities", query=query, filters=filters)
+        url = self._make_url('entities', query=query, filters=filters)
         return APIResultSet(self, url)
 
     def get_collection(self, collection_id):
         """Get a single collection by ID (not foreign ID!)."""
-        url = self._make_url("collections/{0}".format(collection_id))
-        return self._request("GET", url)
+        url = self._make_url('collections/{0}'.format(collection_id))
+        return self._request('GET', url)
 
     def get_entity(self, entity_id):
         """Get a single entity by ID."""
-        url = self._make_url("entities/{0}".format(entity_id))
-        return self._request("GET", url)
+        url = self._make_url('entities/{0}'.format(entity_id))
+        return self._request('GET', url)
 
     def get_collection_by_foreign_id(self, foreign_id):
         """Get a dict representing a collection based on its foreign ID."""
@@ -194,8 +193,7 @@ class AlephAPI(object):
         url = self._make_url("collections/{0}/mapping".format(collection_id))
         return self._request("PUT", url, json=mapping)
 
-    def stream_entities(self, collection_id=None, include=None,
-                        schema=None, decode_json=True):
+    def stream_entities(self, collection_id=None, include=None, schema=None):
         """Iterate over all entities in the given collection.
 
         params
@@ -212,15 +210,11 @@ class AlephAPI(object):
             res = self.session.get(url, params=params, stream=True)
             res.raise_for_status()
             for entity in res.iter_lines():
-                if isinstance(entity, six.binary_type):
+                if isinstance(entity, bytes):
                     entity = entity.decode('utf-8')
                 entity = json.loads(entity)
-                properties = entity.get('properties')
-                if properties is not None and 'id' in entity:
-                    values = properties.get('alephUrl', [])
-                    aleph_url = 'entities/%s' % entity.get('id')
-                    values.append(self._make_url(aleph_url))
-                    properties['alephUrl'] = values
+                aleph_url = 'entities/%s' % entity.get('id')
+                prop_push(entity, 'alephUrl', self._make_url(aleph_url))
                 yield entity
         except RequestException as exc:
             raise AlephException(exc)
@@ -275,6 +269,12 @@ class AlephAPI(object):
         except RequestException as exc:
             raise AlephException(exc)
 
+    def linkages(self, context_ids=None):
+        """Stream all linkages within the given role contexts."""
+        filters = [('context_id', c) for c in ensure_list(context_ids)]
+        url = self._make_url('linkages', filters=filters)
+        return APIResultSet(self, url)
+
     def ingest_upload(self, collection_id, file_path=None, metadata=None):
         """
         Create an empty folder in a collection or upload a document to it
