@@ -5,11 +5,6 @@ import random
 import logging
 from banal import is_listish, is_mapping, ensure_list
 
-try:
-    from pathlib import Path  # noqa
-except ImportError:
-    from pathlib2 import Path  # noqa
-
 log = logging.getLogger(__name__)
 
 
@@ -44,3 +39,10 @@ def resolve_includes(file_path, data):
         for key, value in data.items():
             data[key] = resolve_includes(file_path, value)
     return data
+
+
+def prop_push(entity, prop, value):
+    properties = entity.get('properties', {})
+    values = ensure_list(properties.get(prop))
+    values.extend(ensure_list(value))
+    properties[prop] = values
